@@ -1,8 +1,6 @@
 # pylint: disable=missing-module-docstring
-from policy_sentry.command import analyze
 from policy_sentry.command import initialize
 from policy_sentry.command import write_policy
 from policy_sentry.command import write_policy_dir
 from policy_sentry.command import create_template
-from policy_sentry.command import download_policies
 from policy_sentry.command import query
